# Generated by Django 4.2.16 on 2025-05-07 01:35

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("subscriptionmanager", "0024_productaddonsummary_key"),
    ]

    operations = [
        migrations.AddField(
            model_name="subscriptionsummary",
            name="original_billing_date",
            field=models.DateField(blank=True, null=True),
        ),
        migrations.AddField(
            model_name="subscriptionsummary",
            name="original_plan",
            field=models.CharField(blank=True, max_length=100, null=True),
        ),
        migrations.AddField(
            model_name="subscriptionsummary",
            name="original_signing_date",
            field=models.DateField(blank=True, null=True),
        ),
        migrations.AddField(
            model_name="subscriptionsummary",
            name="original_total_contract_price",
            field=models.DecimalField(
                blank=True, decimal_places=2, max_digits=10, null=True
            ),
        ),
        migrations.AddField(
            model_name="subscriptionsummary",
            name="original_total_contracted_staff_licenses",
            field=models.IntegerField(blank=True, null=True),
        ),
    ]



# Generated by Django 4.2.16 on 2025-03-04 04:31

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("workforce", "0019_usersummaryrow_addons"),
    ]

    operations = [
        migrations.CreateModel(
            name="LatestUsageMetrics",
            fields=[
                (
                    "id",
                    models.BigAutoField(
                        auto_created=True,
                        primary_key=True,
                        serialize=False,
                        verbose_name="ID",
                    ),
                ),
                ("workspace", models.CharField(max_length=200)),
                ("account_number", models.CharField(max_length=50)),
                ("subscription_currency", models.CharField(max_length=3)),
                ("month_start", models.DateField()),
                ("dimension", models.CharField(max_length=200)),
                ("value", models.BigIntegerField()),
                ("as_of", models.DateTimeField()),
            ],
            options={
                "db_table": 'workforce"."mv_usage_metrics_latest',
                "managed": True,
            },
        ),
        migrations.AddConstraint(
            model_name="latestusagemetrics",
            constraint=models.UniqueConstraint(
                fields=("workspace", "dimension", "month_start"),
                name="idx_mvusagemetricslatest",
            ),
        ),
    ]



# Generated by Django 3.2.16 on 2024-06-23 09:19

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("subscriptionmanager", "0008_auto_20240531_1445"),
    ]

    operations = [
        migrations.AddField(
            model_name="subscriptionsummary",
            name="billing_entity_name",
            field=models.CharField(default="", max_length=250),
            preserve_default=False,
        ),
    ]



# Create your models here.

from django.db import models

from .. import model_settings


class MixpanelUserCohort(models.Model):
    """Mixpanel user cohort information per user row"""

    last_synced = models.DateTimeField(auto_now_add=True)
    user_slug = models.TextField(
        db_index=True, help_text="User's unique identifier eg: arafire_321"
    )
    # Editable name of the cohort
    cohort_name = models.CharField(
        max_length=150, db_index=True, help_text="Cohort name from Mixpanel", default=""
    )
    # This is stored as a string because mixpanel cohort_id is a string
    cohort_id = models.TextField(
        db_index=True, help_text="Cohort ID from Mixpanel", default=""
    )

    class Meta:
        managed = model_settings.DATAWAREHOUSE_MANAGED_MODELS
        app_label = "mixpanel"

        default_permissions = ()
        db_table = 'mixpanel"."mixpanel_user_cohort'
        unique_together = ("user_slug", "cohort_id")



# Generated by Django 4.2.16 on 2025-05-02 18:33

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        (
            "subscriptionmanager",
            "0022_delete_accountcodemap_delete_groupaccountcategory",
        ),
    ]

    operations = [
        migrations.CreateModel(
            name="ProductAddonSummary",
            fields=[
                (
                    "id",
                    models.BigAutoField(
                        auto_created=True,
                        primary_key=True,
                        serialize=False,
                        verbose_name="ID",
                    ),
                ),
                ("last_synced", models.DateTimeField()),
                ("name", models.CharField(max_length=100)),
                ("is_usage_based", models.BooleanField(default=True)),
                (
                    "price_aud",
                    models.DecimalField(
                        blank=True, decimal_places=2, max_digits=10, null=True
                    ),
                ),
                (
                    "price_nzd",
                    models.DecimalField(
                        blank=True, decimal_places=2, max_digits=10, null=True
                    ),
                ),
                (
                    "price_gbp",
                    models.DecimalField(
                        blank=True, decimal_places=2, max_digits=10, null=True
                    ),
                ),
                (
                    "price_cad",
                    models.DecimalField(
                        blank=True, decimal_places=2, max_digits=10, null=True
                    ),
                ),
                (
                    "price_usd",
                    models.DecimalField(
                        blank=True, decimal_places=2, max_digits=10, null=True
                    ),
                ),
                (
                    "price_eur",
                    models.DecimalField(
                        blank=True, decimal_places=2, max_digits=10, null=True
                    ),
                ),
                ("is_current", models.BooleanField(default=True)),
            ],
            options={
                "db_table": 'subscriptionmanager"."product_addon_summary',
                "managed": True,
                "default_permissions": (),
            },
        ),
    ]



# Generated by Django 3.2.16 on 2023-01-21 02:47

from decimal import Decimal

import django.contrib.postgres.fields
from django.db import migrations, models


class Migration(migrations.Migration):
    initial = True

    dependencies = [
        ("subscriptionmanager", "0001_schema"),
    ]

    operations = [
        migrations.CreateModel(
            name="ChangeSummary",
            fields=[
                (
                    "id",
                    models.BigAutoField(
                        auto_created=True,
                        primary_key=True,
                        serialize=False,
                        verbose_name="ID",
                    ),
                ),
                ("last_synced", models.DateTimeField()),
                ("subscription_guid", models.UUIDField()),
                ("customer_name", models.CharField(max_length=200)),
                ("customer_account_number", models.CharField(max_length=50)),
                ("currency", models.CharField(max_length=3)),
                ("change_type", models.TextField(null=True)),
                ("date", models.DateField()),
                ("note", models.TextField(blank=True)),
                ("amount", models.DecimalField(decimal_places=2, max_digits=10)),
                ("salesperson", models.CharField(max_length=200)),
            ],
            options={
                "db_table": 'subscriptionmanager"."billing_change_summary',
                "managed": True,
                "default_permissions": (),
            },
        ),
        migrations.CreateModel(
            name="ChargeSummary",
            fields=[
                (
                    "id",
                    models.BigAutoField(
                        auto_created=True,
                        primary_key=True,
                        serialize=False,
                        verbose_name="ID",
                    ),
                ),
                ("last_synced", models.DateTimeField(null=True)),
                ("created", models.DateTimeField(null=True)),
                ("updated", models.DateTimeField(null=True)),
                ("requestor", models.CharField(max_length=200)),
                ("subscription_guid", models.UUIDField()),
                ("customer_name", models.CharField(max_length=200)),
                ("customer_account_number", models.CharField(max_length=50)),
                ("currency", models.CharField(max_length=3)),
                ("itemcode", models.CharField(max_length=20)),
                ("description", models.CharField(max_length=500)),
                ("account_code", models.CharField(max_length=20)),
                ("quantity", models.DecimalField(decimal_places=2, max_digits=10)),
                ("amount", models.DecimalField(decimal_places=2, max_digits=10)),
                ("tracking_category_1", models.CharField(max_length=50)),
                ("tracking_category_2", models.CharField(max_length=50)),
                ("subtotal", models.DecimalField(decimal_places=2, max_digits=10)),
                ("total", models.DecimalField(decimal_places=2, max_digits=10)),
                ("invoice_date", models.DateField(null=True)),
                ("invoice_reference", models.CharField(max_length=20, null=True)),
                ("invoice_number", models.CharField(max_length=20, null=True)),
            ],
            options={
                "db_table": 'subscriptionmanager"."billing_charge_summary',
                "managed": True,
                "default_permissions": (),
            },
        ),
        migrations.CreateModel(
            name="PaymentMethodSummary",
            fields=[
                (
                    "id",
                    models.BigAutoField(
                        auto_created=True,
                        primary_key=True,
                        serialize=False,
                        verbose_name="ID",
                    ),
                ),
                ("last_synced", models.DateTimeField()),
                ("customer_account_number", models.CharField(max_length=50)),
                ("gocardless_id", models.CharField(max_length=100)),
                ("stripe_id", models.CharField(max_length=100)),
                ("description", models.CharField(blank=True, max_length=250)),
            ],
            options={
                "db_table": 'subscriptionmanager"."billing_paymentmethod_summary',
                "managed": True,
                "default_permissions": (),
            },
        ),
        migrations.CreateModel(
            name="RecurringCreditSummary",
            fields=[
                (
                    "id",
                    models.BigAutoField(
                        auto_created=True,
                        primary_key=True,
                        serialize=False,
                        verbose_name="ID",
                    ),
                ),
                ("last_synced", models.DateTimeField()),
                ("subscription_guid", models.UUIDField()),
                ("customer_name", models.CharField(max_length=200)),
                ("customer_account_number", models.CharField(max_length=50)),
                ("currency", models.CharField(max_length=3)),
                ("start_date", models.DateField()),
                ("review_date", models.DateField(blank=True, null=True)),
                ("expiry_date", models.DateField()),
                ("amount", models.DecimalField(decimal_places=2, max_digits=10)),
                ("invoice_text", models.CharField(max_length=200)),
                ("internal_note", models.CharField(blank=True, max_length=500)),
                ("credit_classification", models.TextField()),
            ],
            options={
                "db_table": 'subscriptionmanager"."billing_recurring_credit_summary',
                "managed": True,
                "default_permissions": (),
            },
        ),
        migrations.CreateModel(
            name="RevenueForecastSummary",
            fields=[
                (
                    "id",
                    models.BigAutoField(
                        auto_created=True,
                        primary_key=True,
                        serialize=False,
                        verbose_name="ID",
                    ),
                ),
                ("last_synced", models.DateTimeField()),
                ("month", models.DateField()),
                (
                    "total_contract_value",
                    models.DecimalField(decimal_places=2, max_digits=10),
                ),
                (
                    "total_credit_value",
                    models.DecimalField(decimal_places=2, max_digits=10),
                ),
                ("signed_value", models.DecimalField(decimal_places=2, max_digits=10)),
                (
                    "starting_value",
                    models.DecimalField(decimal_places=2, max_digits=10),
                ),
                ("subs_total", models.IntegerField()),
                ("subs_total_paying", models.IntegerField()),
                ("subs_starting", models.IntegerField()),
                ("subs_won", models.IntegerField()),
                ("subs_lost", models.IntegerField()),
            ],
            options={
                "db_table": 'subscriptionmanager"."billing_revenueforecast_summary',
                "managed": True,
                "default_permissions": (),
            },
        ),
        migrations.CreateModel(
            name="SubscriptionSummary",
            fields=[
                (
                    "id",
                    models.BigAutoField(
                        auto_created=True,
                        primary_key=True,
                        serialize=False,
                        verbose_name="ID",
                    ),
                ),
                ("last_synced", models.DateTimeField()),
                ("created", models.DateTimeField()),
                ("updated", models.DateTimeField()),
                ("salesperson", models.CharField(max_length=200)),
                ("product", models.CharField(max_length=200, null=True)),
                ("customer_name", models.CharField(max_length=200)),
                (
                    "customer_account_number",
                    models.CharField(db_index=True, max_length=50),
                ),
                ("customer_xero_guid", models.UUIDField(blank=True, null=True)),
                ("customer_primary_contact_name", models.CharField(max_length=200)),
                ("customer_primary_contact_email", models.CharField(max_length=200)),
                ("customer_accounts_contact_name", models.CharField(max_length=200)),
                ("customer_accounts_contact_email", models.CharField(max_length=200)),
                (
                    "customer_company_tax_number",
                    models.CharField(
                        help_text="ABN, NZBN or VAT number.", max_length=50
                    ),
                ),
                ("subscription_guid", models.UUIDField()),
                ("currency", models.CharField(max_length=3)),
                ("signing_date", models.DateField()),
                ("billing_date", models.DateField()),
                ("plan", models.CharField(max_length=100)),
                ("staff_addon_name", models.CharField(max_length=100)),
                ("plan_included_licenses", models.IntegerField(blank=True, null=True)),
                (
                    "additional_committed_staff",
                    models.IntegerField(blank=True, null=True),
                ),
                (
                    "total_contracted_staff_licenses",
                    models.IntegerField(blank=True, null=True),
                ),
                (
                    "override_plan_price",
                    models.DecimalField(
                        blank=True, decimal_places=2, max_digits=10, null=True
                    ),
                ),
                (
                    "override_staff_price",
                    models.DecimalField(
                        blank=True, decimal_places=2, max_digits=10, null=True
                    ),
                ),
                (
                    "effective_discount",
                    models.DecimalField(
                        blank=True, decimal_places=2, max_digits=10, null=True
                    ),
                ),
                (
                    "total_contract_price",
                    models.DecimalField(
                        blank=True, decimal_places=2, max_digits=10, null=True
                    ),
                ),
                (
                    "hosting_addon_price",
                    models.DecimalField(
                        blank=True, decimal_places=2, max_digits=10, null=True
                    ),
                ),
                (
                    "bi_addon_price",
                    models.DecimalField(
                        blank=True, decimal_places=2, max_digits=10, null=True
                    ),
                ),
                (
                    "sla_addon_price",
                    models.DecimalField(
                        blank=True, decimal_places=2, max_digits=10, null=True
                    ),
                ),
                (
                    "workspaces",
                    django.contrib.postgres.fields.ArrayField(
                        base_field=models.CharField(max_length=50),
                        blank=True,
                        default=list,
                        size=None,
                    ),
                ),
                ("termination_date", models.DateField(blank=True, null=True)),
                ("termination_code", models.TextField(blank=True)),
                ("termination_reason", models.TextField(blank=True)),
                (
                    "current_expansion_chargeable",
                    models.DecimalField(
                        blank=True, decimal_places=2, max_digits=10, null=True
                    ),
                ),
                (
                    "current_total_mrr_chargeable",
                    models.DecimalField(
                        blank=True, decimal_places=2, max_digits=10, null=True
                    ),
                ),
                (
                    "current_total_used_staff_licenses",
                    models.IntegerField(blank=True, null=True),
                ),
                (
                    "current_total_additional_chargable_licenses",
                    models.IntegerField(blank=True, null=True),
                ),
                (
                    "current_monthly_recurring_credit",
                    models.DecimalField(
                        blank=True, decimal_places=2, max_digits=10, null=True
                    ),
                ),
                (
                    "lastmonth_expansion_charged",
                    models.DecimalField(
                        blank=True, decimal_places=2, max_digits=10, null=True
                    ),
                ),
                (
                    "lastmonth_total_mrr_charged",
                    models.DecimalField(
                        blank=True, decimal_places=2, max_digits=10, null=True
                    ),
                ),
                (
                    "lastmonth_total_used_staff_licenses",
                    models.IntegerField(blank=True, null=True),
                ),
                (
                    "lastmonth_total_used_desk_licenses",
                    models.IntegerField(blank=True, null=True),
                ),
                (
                    "lastmonth_total_used_field_licenses",
                    models.IntegerField(blank=True, null=True),
                ),
                (
                    "lastmonth_total_additional_chargable_licenses",
                    models.IntegerField(blank=True, null=True),
                ),
            ],
            options={
                "db_table": 'subscriptionmanager"."billing_subscription_summary',
                "managed": True,
                "default_permissions": (),
            },
        ),
        migrations.CreateModel(
            name="WorkspaceSummary",
            fields=[
                ("last_synced", models.DateTimeField()),
                ("guid", models.UUIDField(primary_key=True, serialize=False)),
                ("name", models.CharField(max_length=50)),
                ("customer_account_number", models.CharField(max_length=50)),
                ("subscription_guid", models.UUIDField()),
            ],
            options={
                "db_table": 'subscriptionmanager"."billing_workspace_summary',
                "managed": True,
                "default_permissions": (),
            },
        ),
        migrations.CreateModel(
            name="XeroContactSummary",
            fields=[
                (
                    "id",
                    models.BigAutoField(
                        auto_created=True,
                        primary_key=True,
                        serialize=False,
                        verbose_name="ID",
                    ),
                ),
                ("last_synced", models.DateTimeField()),
                ("customer_name", models.CharField(max_length=200, null=True)),
                ("customer_account_number", models.CharField(max_length=50, null=True)),
                ("customer_first_name", models.CharField(max_length=100, null=True)),
                ("customer_last_name", models.CharField(max_length=100, null=True)),
            ],
            options={
                "db_table": 'subscriptionmanager"."billing_xero_customer_summary',
                "managed": True,
                "default_permissions": (),
            },
        ),
        migrations.CreateModel(
            name="XeroInvoiceSummary",
            fields=[
                (
                    "id",
                    models.BigAutoField(
                        auto_created=True,
                        primary_key=True,
                        serialize=False,
                        verbose_name="ID",
                    ),
                ),
                ("last_synced", models.DateTimeField()),
                ("invoice_guid", models.UUIDField()),
                ("contact_guid", models.UUIDField()),
                ("contact_name", models.CharField(max_length=200)),
                ("contact_account_number", models.CharField(max_length=50)),
                ("number", models.CharField(max_length=50)),
                ("reference", models.CharField(max_length=100)),
                ("date", models.DateField(blank=True, null=True)),
                ("due_date", models.DateField(blank=True, null=True)),
                (
                    "subtotal",
                    models.DecimalField(
                        decimal_places=2, default=Decimal("0.00"), max_digits=10
                    ),
                ),
                (
                    "total",
                    models.DecimalField(
                        decimal_places=2, default=Decimal("0.00"), max_digits=10
                    ),
                ),
                ("status", models.CharField(max_length=50)),
                ("currency", models.CharField(max_length=3)),
                (
                    "currency_rate",
                    models.DecimalField(
                        decimal_places=2, default=Decimal("0.00"), max_digits=10
                    ),
                ),
                ("is_sent", models.BooleanField(default=False)),
                ("repeating_invoice_guid", models.UUIDField(null=True)),
                (
                    "amount_due",
                    models.DecimalField(
                        decimal_places=2, default=Decimal("0.00"), max_digits=10
                    ),
                ),
                (
                    "amount_paid",
                    models.DecimalField(
                        decimal_places=2, default=Decimal("0.00"), max_digits=10
                    ),
                ),
                ("fully_paid_on_date", models.DateField(blank=True, null=True)),
            ],
            options={
                "db_table": 'subscriptionmanager"."billing_xero_invoice_summary',
                "managed": True,
                "default_permissions": (),
            },
        ),
    ]



# Generated by Django 3.2.16 on 2024-03-22 05:53

from decimal import Decimal

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("subscriptionmanager", "0004_auto_20231009_1407"),
    ]

    operations = [
        migrations.CreateModel(
            name="ConsolidatedProfitAndLossMonth",
            fields=[
                (
                    "id",
                    models.BigAutoField(
                        auto_created=True,
                        primary_key=True,
                        serialize=False,
                        verbose_name="ID",
                    ),
                ),
                ("last_synced", models.DateTimeField()),
                ("entity_name", models.CharField(max_length=200)),
                ("date", models.DateField()),
                ("local_account_code", models.CharField(max_length=100)),
                ("local_account_name", models.CharField(max_length=300)),
                ("local_account_category", models.CharField(max_length=300)),
                ("group_account_code", models.CharField(max_length=100)),
                ("group_account_name", models.CharField(max_length=300)),
                (
                    "subtotal",
                    models.DecimalField(
                        decimal_places=2, default=Decimal("0.00"), max_digits=10
                    ),
                ),
                ("currency", models.CharField(max_length=3)),
                (
                    "reporting_fx_rate",
                    models.DecimalField(
                        decimal_places=2, default=Decimal("0.00"), max_digits=10
                    ),
                ),
                (
                    "reporting_subtotal",
                    models.DecimalField(
                        decimal_places=2, default=Decimal("0.00"), max_digits=10
                    ),
                ),
                ("reporting_region", models.CharField(max_length=200)),
            ],
            options={
                "db_table": 'subscriptionmanager"."consolidated_profit_and_loss_month',
                "managed": True,
                "default_permissions": (),
            },
        ),
    ]



from django.db import models

from .. import model_settings


class AccountCodeMap(models.Model):
    entity_name = models.CharField(max_length=200)
    local_account_name = models.CharField(max_length=200)
    group_account_name = models.CharField(max_length=200)
    last_synced = models.DateTimeField(db_index=True)

    class Meta:
        managed = model_settings.DATAWAREHOUSE_MANAGED_MODELS
        app_label = "finance"
        default_permissions = ()
        db_table = 'finance"."account_code_map'


class GroupAccountCategory(models.Model):
    group_account_name = models.CharField(max_length=200)
    department = models.CharField(max_length=200)
    category1 = models.CharField(max_length=200)
    category2 = models.CharField(max_length=200)
    category3 = models.CharField(max_length=200)
    category4 = models.CharField(max_length=200)
    category5 = models.CharField(max_length=200)
    last_synced = models.DateTimeField(db_index=True)

    class Meta:
        managed = model_settings.DATAWAREHOUSE_MANAGED_MODELS
        app_label = "finance"
        default_permissions = ()
        db_table = 'finance"."group_account_category'



# Generated by Django 4.2.16 on 2025-07-03 14:14

import datetime

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("subscriptionmanager", "0029_invoicelineitemsummary"),
    ]

    operations = [
        migrations.AlterField(
            model_name="subscriptionsummary",
            name="original_billing_date",
            field=models.DateField(blank=True, default=datetime.date(1900, 1, 1)),
            preserve_default=False,
        ),
        migrations.AlterField(
            model_name="subscriptionsummary",
            name="original_signing_date",
            field=models.DateField(blank=True, default=datetime.date(1900, 1, 1)),
            preserve_default=False,
        ),
    ]



# Generated by Django 3.2.16 on 2024-07-11 00:31

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("subscriptionmanager", "0010_auto_20240623_2142"),
    ]

    operations = [
        migrations.AddField(
            model_name="subscriptionsummary",
            name="deal_originator",
            field=models.CharField(max_length=200, null=True),
        ),
    ]



# Generated by Django 4.2.16 on 2025-07-01 07:17

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("subscriptionmanager", "0026_rollforwardsummary_product_expansion_and_more"),
    ]

    operations = [
        migrations.AlterField(
            model_name="xeroinvoicesummary",
            name="reference",
            field=models.CharField(max_length=100, null=True, blank=True),
        ),
    ]



# Generated by Django 4.2.16 on 2024-09-07 11:59

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("mixpanel", "0002_initial"),
    ]

    operations = [
        migrations.AlterField(
            model_name="mixpanelusercohort",
            name="cohort_name",
            field=models.CharField(
                db_index=True,
                default="",
                help_text="Cohort name from Mixpanel",
                max_length=150,
            ),
        ),
    ]



# Generated by Django 4.2.16 on 2025-07-02 01:02

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("subscriptionmanager", "0028_fixedfxrate"),
    ]

    operations = [
        migrations.CreateModel(
            name="InvoiceLineItemSummary",
            fields=[
                (
                    "id",
                    models.BigAutoField(
                        auto_created=True,
                        primary_key=True,
                        serialize=False,
                        verbose_name="ID",
                    ),
                ),
                ("last_synced", models.DateTimeField(null=True)),
                ("customer_account_number", models.CharField(max_length=25)),
                ("account_code", models.CharField(max_length=20)),
                ("key", models.CharField(blank=True, max_length=100, null=True)),
                ("currency", models.CharField(max_length=3)),
                ("quantity", models.DecimalField(decimal_places=2, max_digits=10)),
                ("amount", models.DecimalField(decimal_places=2, max_digits=10)),
                (
                    "discount",
                    models.DecimalField(
                        blank=True, decimal_places=2, max_digits=5, null=True
                    ),
                ),
                ("tax_rate", models.CharField(max_length=20)),
                ("subtotal", models.DecimalField(decimal_places=2, max_digits=10)),
                ("total", models.DecimalField(decimal_places=2, max_digits=10)),
            ],
            options={
                "db_table": 'subscriptionmanager"."invoice_line_item_summary',
                "managed": True,
                "default_permissions": (),
            },
        ),
    ]



# Generated by Django 3.2.16 on 2023-10-09 14:07

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("subscriptionmanager", "0003_auto_20230123_0443"),
    ]

    operations = [
        migrations.AddField(
            model_name="revenueforecastsummary",
            name="downgrades_book",
            field=models.DecimalField(decimal_places=2, max_digits=10, null=True),
        ),
        migrations.AddField(
            model_name="revenueforecastsummary",
            name="downgrades_contract",
            field=models.DecimalField(decimal_places=2, max_digits=10, null=True),
        ),
        migrations.AddField(
            model_name="revenueforecastsummary",
            name="loss_value",
            field=models.DecimalField(decimal_places=2, max_digits=10, null=True),
        ),
        migrations.AddField(
            model_name="revenueforecastsummary",
            name="new_paying_value",
            field=models.DecimalField(decimal_places=2, max_digits=10, null=True),
        ),
        migrations.AddField(
            model_name="revenueforecastsummary",
            name="total_contract_paying_value",
            field=models.DecimalField(decimal_places=2, max_digits=10, null=True),
        ),
        migrations.AddField(
            model_name="revenueforecastsummary",
            name="upgrades_book",
            field=models.DecimalField(decimal_places=2, max_digits=10, null=True),
        ),
        migrations.AddField(
            model_name="revenueforecastsummary",
            name="upgrades_contract",
            field=models.DecimalField(decimal_places=2, max_digits=10, null=True),
        ),
    ]



# Generated by Paul on 2024-12-02 15:09

from django.db import migrations
from django.db.models import F


def fix_routine_performance_metrics(apps, schema):
    UsageMetrics = apps.get_model("workforce", "UsageMetrics")

    UsageMetrics.objects.filter(
        count_name="rolling_1_month_routine_performance"
    ).update(
        count_name="rolling_one_month_routine_performance",
        stat_count=F("stat_count") / 100,
    )

    UsageMetrics.objects.filter(
        count_name="rolling_12_month_routine_performance"
    ).update(
        count_name="rolling_twelve_month_routine_performance",
        stat_count=F("stat_count") / 100,
    )


class Migration(migrations.Migration):
    dependencies = [
        ("workforce", "0017_benchmark_delete_benchmarkdatapoint"),
    ]

    operations = [
        migrations.RunPython(code=fix_routine_performance_metrics, elidable=True),
    ]



# Generated by Django 4.2.16 on 2025-01-04 00:09

import django.contrib.postgres.fields
from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("workforce", "0018_fix_routine_usage_metrics"),
    ]

    operations = [
        migrations.AddField(
            model_name="usersummaryrow",
            name="addons",
            field=django.contrib.postgres.fields.ArrayField(
                base_field=models.CharField(max_length=150),
                blank=True,
                default=list,
                size=None,
            ),
        ),
    ]



# Generated by Django 3.2.16 on 2023-10-10 19:14

import django.contrib.postgres.fields
from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("workforce", "0008_remove_constancesetting_last_reported"),
    ]

    operations = [
        migrations.CreateModel(
            name="TemplateStatSummary",
            fields=[
                (
                    "id",
                    models.BigAutoField(
                        auto_created=True,
                        primary_key=True,
                        serialize=False,
                        verbose_name="ID",
                    ),
                ),
                ("last_synced", models.DateTimeField(db_index=True)),
                ("tenant", models.CharField(db_index=True, max_length=200)),
                ("object_pk", models.IntegerField()),
                ("object_content_type_name", models.CharField(max_length=100)),
                ("created", models.DateTimeField()),
                ("region", models.CharField(max_length=10)),
                ("name", models.CharField(max_length=250)),
                ("key", models.CharField(max_length=250)),
                ("extends", models.CharField(blank=True, default="", max_length=250)),
                ("usage_total", models.IntegerField()),
                ("usage_this_year", models.IntegerField()),
                ("usage_last_year", models.IntegerField()),
                (
                    "libraries_loaded",
                    django.contrib.postgres.fields.ArrayField(
                        base_field=models.CharField(max_length=250),
                        blank=True,
                        default=list,
                        size=None,
                    ),
                ),
                (
                    "deprecated_functions",
                    django.contrib.postgres.fields.ArrayField(
                        base_field=models.CharField(max_length=250),
                        blank=True,
                        default=list,
                        size=None,
                    ),
                ),
                ("is_active", models.BooleanField()),
            ],
            options={
                "db_table": 'workforce"."template_stat_summary',
                "managed": True,
            },
        ),
    ]



# Generated by Django 4.2.16 on 2025-02-24 21:37

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("subscriptionmanager", "0017_accountcodemap"),
    ]

    operations = [
        migrations.AddField(
            model_name="workspacesummary",
            name="is_sandbox",
            field=models.BooleanField(default=False),
        ),
        migrations.AddField(
            model_name="workspacesummary",
            name="is_suspended",
            field=models.BooleanField(default=False),
        ),
        migrations.AddField(
            model_name="workspacesummary",
            name="is_virtual_only",
            field=models.BooleanField(default=False),
        ),
        migrations.AddField(
            model_name="workspacesummary",
            name="timezone",
            field=models.CharField(default="", max_length=50),
        ),
    ]



# Generated by Django 4.2.16 on 2025-04-16 01:13

from django.db import migrations


class Migration(migrations.Migration):
    dependencies = [
        ("subscriptionmanager", "0021_addonsummary_price_eur_plansummary_price_eur"),
    ]

    operations = [
        migrations.DeleteModel(
            name="AccountCodeMap",
        ),
        migrations.DeleteModel(
            name="GroupAccountCategory",
        ),
    ]



# Generated by Django 4.2.16 on 2025-05-15 05:41

import django.utils.timezone
from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("workforce", "0022_serverusagedata"),
    ]

    operations = [
        migrations.RemoveField(
            model_name="serverusagedata",
            name="as_at",
        ),
        migrations.AddField(
            model_name="serverusagedata",
            name="as_of",
            field=models.DateTimeField(default=django.utils.timezone.now),
            preserve_default=False,
        ),
    ]



# Generated by Django 3.2.16 on 2023-10-05 10:26

from django.db import migrations


class Migration(migrations.Migration):
    dependencies = [
        ("workforce", "0007_auto_20230704_2306"),
    ]

    operations = [
        migrations.RemoveField(
            model_name="constancesetting",
            name="last_reported",
        ),
    ]



# Generated by Django 4.2.16 on 2024-10-08 00:26

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("subscriptionmanager", "0013_rollforwardsummary"),
    ]

    operations = [
        migrations.AddField(
            model_name="subscriptionsummary",
            name="primary_termination_reason",
            field=models.CharField(blank=True, max_length=25),
        ),
    ]



# Generated by Django 4.2.16 on 2025-07-08 09:46

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("subscriptionmanager", "0030_alter_subscription_originals"),
    ]

    operations = [
        migrations.AddField(
            model_name="productaddonsummary",
            name="billing_unit_description",
            field=models.CharField(blank=True, default="", max_length=100),
        ),
        migrations.AddField(
            model_name="productaddonsummary",
            name="description",
            field=models.CharField(blank=True, default="", max_length=200),
        ),
    ]



# Generated by Django 4.2.16 on 2024-09-27 06:31

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("workforce", "0015_auto_20240926_0155"),
    ]

    operations = [
        migrations.CreateModel(
            name="BenchmarkDataPoint",
            fields=[
                (
                    "id",
                    models.BigAutoField(
                        auto_created=True,
                        primary_key=True,
                        serialize=False,
                        verbose_name="ID",
                    ),
                ),
                ("tenant", models.CharField(db_index=True, max_length=200)),
                ("country", models.CharField(db_index=True, max_length=200)),
                ("timestamp", models.DateField(db_index=True)),
                ("benchmark_type", models.CharField(db_index=True, max_length=200)),
                ("value", models.DecimalField(decimal_places=2, max_digits=20)),
            ],
            options={
                "db_table": 'workforce"."benchmarks',
                "managed": True,
                "default_permissions": (),
                "unique_together": {("tenant", "benchmark_type", "timestamp")},
            },
        ),
    ]



# Generated by Django 3.2.16 on 2023-07-04 23:06

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("workforce", "0006_usagemetrics_for_date"),
    ]

    operations = [
        migrations.AlterField(
            model_name="serverusage",
            name="for_date",
            field=models.DateField(db_index=True),
        ),
        migrations.AlterField(
            model_name="serverusage",
            name="tenant",
            field=models.CharField(db_index=True, max_length=200),
        ),
        migrations.AlterField(
            model_name="usagemetrics",
            name="for_date",
            field=models.DateField(db_index=True, null=True),
        ),
        migrations.AddIndex(
            model_name="usagemetrics",
            index=models.Index(
                fields=["tenant", "count_name", "-for_date"],
                name="usage_metrics_date_btree",
            ),
        ),
    ]



# Generated by Django 3.2.16 on 2024-01-16 23:39

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("workforce", "0010_alter_usagemetrics_for_date"),
    ]

    operations = [
        migrations.CreateModel(
            name="SyncedData",
            fields=[
                (
                    "id",
                    models.BigAutoField(
                        auto_created=True,
                        primary_key=True,
                        serialize=False,
                        verbose_name="ID",
                    ),
                ),
                ("tenant", models.CharField(db_index=True, max_length=200)),
                ("key", models.CharField(db_index=True, max_length=200)),
                ("data", models.JSONField()),
                ("last_synced", models.DateTimeField(db_index=True, null=True)),
            ],
            options={
                "db_table": 'workforce"."synced_data',
                "managed": True,
                "default_permissions": (),
                "unique_together": {("tenant", "key")},
            },
        ),
    ]



# Generated by Django 3.2.16 on 2024-07-24 03:44

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("subscriptionmanager", "0010_auto_20240623_2142"),
    ]

    operations = [
        migrations.AddField(
            model_name="subscriptionsummary",
            name="customer_address",
            field=models.CharField(default="", max_length=1000),
            preserve_default=False,
        ),
    ]



# Generated by Django 3.2.16 on 2024-01-17 00:12

import django.core.serializers.json
from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("workforce", "0011_synceddata"),
    ]

    operations = [
        migrations.RemoveField(
            model_name="synceddata",
            name="data",
        ),
        migrations.AddField(
            model_name="synceddata",
            name="oauth_state",
            field=models.JSONField(
                decoder=django.core.serializers.json.DjangoJSONEncoder,
                default=list,
                encoder=django.core.serializers.json.DjangoJSONEncoder,
            ),
        ),
    ]



# Generated by Django 4.2.16 on 2025-05-15 01:16

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("workforce", "0021_delete_onboardingactionrow_and_more"),
    ]

    operations = [
        migrations.CreateModel(
            name="ServerUsageData",
            fields=[
                (
                    "id",
                    models.BigAutoField(
                        auto_created=True,
                        primary_key=True,
                        serialize=False,
                        verbose_name="ID",
                    ),
                ),
                ("workspace", models.CharField(db_index=True, max_length=50)),
                ("for_date", models.DateField(db_index=True)),
                ("as_at", models.DateField()),
                ("usage_key", models.CharField(db_index=True, max_length=100)),
                ("amount", models.IntegerField(default=0)),
                ("data", models.JSONField(blank=True, null=True)),
            ],
            options={
                "db_table": 'workforce"."server_usage_data',
                "managed": True,
                "default_permissions": (),
                "unique_together": {("workspace", "for_date", "usage_key")},
            },
        ),
    ]



# Generated by Django 3.2.16 on 2024-07-24 04:36

from django.db import migrations


class Migration(migrations.Migration):
    dependencies = [
        ("subscriptionmanager", "0011_subscriptionsummary_customer_address"),
        ("subscriptionmanager", "0011_subscriptionsummary_deal_originator"),
    ]

    operations = []



# Generated by Django 4.2.16 on 2025-02-14 22:21

import django.contrib.postgres.fields
from django.db import migrations, models


class Migration(migrations.Migration):
    initial = True

    dependencies = [
        ("hubspot", "0001_schema"),
    ]

    operations = [
        migrations.CreateModel(
            name="CustomerContacts",
            fields=[
                (
                    "id",
                    models.BigAutoField(
                        auto_created=True,
                        primary_key=True,
                        serialize=False,
                        verbose_name="ID",
                    ),
                ),
                ("name", models.CharField(max_length=255)),
                ("email", models.CharField(max_length=200)),
                ("tenant", models.CharField(db_index=True, max_length=200)),
                ("license", models.CharField(db_index=True, max_length=10)),
                (
                    "groups",
                    django.contrib.postgres.fields.ArrayField(
                        base_field=models.CharField(max_length=150),
                        blank=True,
                        default=list,
                        size=None,
                    ),
                ),
                ("currency", models.CharField(max_length=3)),
            ],
            options={
                "db_table": 'hubspot"."customer_contacts',
                "managed": False,
                "default_permissions": (),
            },
        ),
    ]



# Generated by Django 4.2.16 on 2024-10-03 05:23

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("workforce", "0016_benchmarkdatapoint"),
    ]

    operations = [
        migrations.CreateModel(
            name="Benchmark",
            fields=[
                (
                    "id",
                    models.BigAutoField(
                        auto_created=True,
                        primary_key=True,
                        serialize=False,
                        verbose_name="ID",
                    ),
                ),
                ("count_name", models.CharField(max_length=200)),
                ("country_cohort", models.CharField(max_length=200)),
                ("size_cohort", models.CharField(max_length=20)),
                ("industry_cohort", models.CharField(max_length=20)),
                ("value", models.DecimalField(decimal_places=2, max_digits=20)),
                ("tenant_count", models.IntegerField()),
            ],
            options={
                "db_table": 'workforce"."usage_metrics_benchmarks',
                "managed": False,
                "default_permissions": (),
            },
        ),
        migrations.DeleteModel(
            name="BenchmarkDataPoint",
        ),
    ]



# Generated by Django 3.2.16 on 2023-04-12 00:27

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("workforce", "0003_serverusage_contractor_addons_used"),
    ]

    operations = [
        migrations.CreateModel(
            name="CustomReportSummary",
            fields=[
                (
                    "id",
                    models.BigAutoField(
                        auto_created=True,
                        primary_key=True,
                        serialize=False,
                        verbose_name="ID",
                    ),
                ),
                ("tenant", models.CharField(db_index=True, max_length=200)),
                ("last_synced", models.DateTimeField(db_index=True)),
                ("custom_report_pk", models.PositiveIntegerField(db_index=True)),
                ("query", models.TextField()),
            ],
            options={
                "db_table": 'workforce"."customer_custom_reports',
                "managed": True,
                "default_permissions": (),
            },
        ),
    ]



# Generated by Django 4.2.16 on 2024-09-07 10:51

from django.db import migrations, models


class Migration(migrations.Migration):
    initial = True

    dependencies = [
        ("mixpanel", "0001_schema"),
    ]

    operations = [
        migrations.CreateModel(
            name="MixpanelUserCohort",
            fields=[
                (
                    "id",
                    models.BigAutoField(
                        auto_created=True,
                        primary_key=True,
                        serialize=False,
                        verbose_name="ID",
                    ),
                ),
                ("last_synced", models.DateTimeField(auto_now_add=True)),
                (
                    "user_slug",
                    models.TextField(
                        db_index=True,
                        help_text="User's unique identifier eg: arafire_321",
                    ),
                ),
                (
                    "cohort_name",
                    models.TextField(
                        db_index=True, default="", help_text="Cohort name from Mixpanel"
                    ),
                ),
                (
                    "cohort_id",
                    models.TextField(
                        db_index=True, default="", help_text="Cohort ID from Mixpanel"
                    ),
                ),
            ],
            options={
                "db_table": 'mixpanel"."mixpanel_user_cohort',
                "managed": True,
                "default_permissions": (),
                "unique_together": {("user_slug", "cohort_id")},
            },
        ),
    ]



# Generated by Django 3.2.16 on 2023-02-05 23:37

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("workforce", "0002_initial"),
    ]

    operations = [
        migrations.AddField(
            model_name="serverusage",
            name="contractor_addons_used",
            field=models.IntegerField(default=0),
        ),
    ]



# Generated by Django 3.2.16 on 2024-09-26 01:55

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("workforce", "0014_alter_synceddata_data"),
    ]

    operations = [
        migrations.AddField(
            model_name="serverusage",
            name="premium_portal_buildings",
            field=models.IntegerField(default=0),
        ),
        migrations.AddField(
            model_name="serverusage",
            name="premium_portal_tenancies",
            field=models.IntegerField(default=0),
        ),
        migrations.AddField(
            model_name="serverusage",
            name="sms_notifications",
            field=models.IntegerField(default=0),
        ),
    ]



# Generated by Django 4.2.16 on 2024-12-12 23:49

import django.contrib.postgres.fields
from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("subscriptionmanager", "0014_subscriptionsummary_primary_termination_reason"),
    ]

    operations = [
        migrations.CreateModel(
            name="Workspace",
            fields=[
                (
                    "id",
                    models.BigAutoField(
                        auto_created=True,
                        primary_key=True,
                        serialize=False,
                        verbose_name="ID",
                    ),
                ),
                ("name", models.CharField(max_length=30)),
                ("customer", models.CharField(max_length=30)),
                ("cluster", models.CharField()),
                ("account_number", models.CharField(max_length=25, null=True)),
                (
                    "tags",
                    django.contrib.postgres.fields.ArrayField(
                        base_field=models.CharField(), null=True, size=None
                    ),
                ),
            ],
            options={
                "db_table": 'subscriptionmanager"."workspace',
                "managed": True,
                "default_permissions": (),
            },
        ),
    ]



# Generated by Django 4.2.16 on 2025-03-23 04:56

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("subscriptionmanager", "0019_groupaccountcategory"),
    ]

    operations = [
        migrations.AddField(
            model_name="rollforwardsummary",
            name="customer_group_code",
            field=models.CharField(default="", max_length=50),
            preserve_default=False,
        ),
        migrations.AddField(
            model_name="subscriptionsummary",
            name="customer_group_code",
            field=models.CharField(db_index=True, default="", max_length=50),
            preserve_default=False,
        ),
    ]



from django.contrib.postgres.fields import ArrayField
from django.db import models


class CustomerContacts(models.Model):
    name = models.CharField(max_length=255)
    email = models.CharField(max_length=200)
    tenant = models.CharField(db_index=True, max_length=200)
    license = models.CharField(max_length=10, db_index=True)
    groups = ArrayField(models.CharField(max_length=150), default=list, blank=True)
    currency = models.CharField(max_length=3)

    class Meta:
        # Created via a view
        managed = False
        app_label = "hubspot"
        default_permissions = ()
        db_table = 'hubspot"."customer_contacts'



# Generated by Django 3.2.16 on 2024-01-17 00:58

import django.core.serializers.json
from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("workforce", "0013_rename_oauth_state_synceddata_data"),
    ]

    operations = [
        migrations.AlterField(
            model_name="synceddata",
            name="data",
            field=models.JSONField(
                default=list, encoder=django.core.serializers.json.DjangoJSONEncoder
            ),
        ),
    ]



# Generated by Django 4.2.16 on 2025-01-04 00:57

import django.contrib.postgres.fields
from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("subscriptionmanager", "0015_workspace"),
    ]

    operations = [
        migrations.AlterField(
            model_name="workspace",
            name="name",
            field=models.CharField(max_length=30, unique=True),
        ),
        migrations.AlterField(
            model_name="workspace",
            name="tags",
            field=django.contrib.postgres.fields.ArrayField(
                base_field=models.CharField(), default=list, size=None
            ),
        ),
        migrations.AddIndex(
            model_name="workspace",
            index=models.Index(fields=["cluster"], name="workspace_cluster_3a614d_idx"),
        ),
    ]



from unittest.mock import MagicMock, patch

from django.test import TestCase
from tickforge_client.models import Cluster, ServerTimezone, WorkspaceCluster
from tickforge_client.models import Workspace as TickforgeWorkspace

from app.core.tasks import sync_workspaces_from_tickforge
from uptick_datawarehouse.subscriptionmanager.models import (
    Workspace as DataWarehouseWorkspace,
)

mock_tickforge_workspaces = [
    TickforgeWorkspace(
        name="workspace1",
        customer="customer1",
        timezone=ServerTimezone.TZ_AU,  # type: ignore
        cluster=WorkspaceCluster(Cluster.PROD_MINUS_AU_MINUS_1),
        tags=["workforce", "customer", "production", "tz_au"],
    ),
    TickforgeWorkspace(
        name="workspace2",
        customer="customer2",
        timezone=ServerTimezone.TZ_GB,  # type: ignore
        cluster=WorkspaceCluster(Cluster.PROD_MINUS_GB_MINUS_1),
        tags=["workforce", "customer", "production", "tz_gb"],
    ),
    TickforgeWorkspace(
        name="workspace3",
        customer="customer3",
        timezone=ServerTimezone.TZ_NZ,  # type: ignore
        cluster=WorkspaceCluster(Cluster.PROD_MINUS_AU_MINUS_2),
        tags=["customer", "production", "tz_nz"],
    ),
]


@patch("boto3.client", return_value=MagicMock())
@patch("tickforge_client.get_access_token", return_value="A JWT Access Token")
@patch(
    "tickforge_client.api.workspaces_api.WorkspacesApi.list_workspaces_api_workspaces_get",
    return_value=mock_tickforge_workspaces,
)
class SyncWorkspacesFromTickforgeTestCase(TestCase):
    def assert_workspaces_equal(
        self,
        tickforge_workspace: TickforgeWorkspace,
        datawarehouse_workspace: DataWarehouseWorkspace,
    ) -> None:
        required_keys = ["name", "customer", "cluster", "tags"]

        tickforge_workspace_dict = tickforge_workspace.to_dict()
        datawarehouse_workspace_dict = datawarehouse_workspace.to_dict()
        tickforge_workspace_dict["cluster"] = tickforge_workspace_dict[
            "cluster"
        ].replace('"', "")
        datawarehouse_workspace_dict["cluster"] = datawarehouse_workspace_dict[
            "cluster"
        ].replace('"', "")
        for required_key in required_keys:
            self.assertEqual(
                tickforge_workspace_dict[required_key],
                datawarehouse_workspace_dict[required_key],
            )

    def test_sync(self, _, __, ___):
        datawarehouse_workspaces = DataWarehouseWorkspace.objects.all()
        self.assertEqual(len(datawarehouse_workspaces), 0)

        sync_workspaces_from_tickforge(None)

        datawarehouse_workspaces = DataWarehouseWorkspace.objects.all()
        self.assertEqual(len(datawarehouse_workspaces), 2)

        mock_tickforge_workspaces_tagged_workforce = list(
            filter(
                lambda mock_tickforge_workspace: "workforce"
                in mock_tickforge_workspace.tags,
                mock_tickforge_workspaces,
            )
        )
        for datawarehouse_workspace, tickforge_workspace in zip(
            datawarehouse_workspaces, mock_tickforge_workspaces_tagged_workforce
        ):
            self.assert_workspaces_equal(datawarehouse_workspace, tickforge_workspace)



# Generated by Django 4.2.16 on 2025-06-04 01:49
from decimal import Decimal

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        (
            "subscriptionmanager",
            "0025_subscriptionsummary_original_billing_date_and_more",
        ),
    ]

    operations = [
        migrations.AddField(
            model_name="rollforwardsummary",
            name="product_expansion",
            field=models.DecimalField(
                decimal_places=2, default=Decimal("0.00"), max_digits=10
            ),
        ),
        migrations.AddField(
            model_name="rollforwardsummary",
            name="product_expansion_mom",
            field=models.DecimalField(
                decimal_places=2, default=Decimal("0.00"), max_digits=10
            ),
        ),
    ]



# Generated by Django 3.2.16 on 2023-06-06 06:58

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("workforce", "0004_customreportsummary"),
    ]

    operations = [
        migrations.AddField(
            model_name="constancesetting",
            name="last_synced",
            field=models.DateTimeField(null=True),
        ),
        migrations.AddField(
            model_name="extensionsummary",
            name="last_synced",
            field=models.DateTimeField(null=True),
        ),
        migrations.AddField(
            model_name="featureflagsummary",
            name="last_synced",
            field=models.DateTimeField(null=True),
        ),
        migrations.AddField(
            model_name="templatechangerequestsummary",
            name="last_synced",
            field=models.DateTimeField(null=True),
        ),
    ]



# Generated by Django 4.2.16 on 2025-09-05 00:49

from decimal import Decimal

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("subscriptionmanager", "0032_rollforwardsummary_pass_through_and_more"),
    ]

    operations = [
        migrations.AddField(
            model_name="rollforwardsummary",
            name="price_increase_upgrade_or_downgrade",
            field=models.DecimalField(
                decimal_places=2, default=Decimal("0.00"), max_digits=10
            ),
        ),
    ]



# Generated by Django 4.2.16 on 2025-05-02 19:44

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("subscriptionmanager", "0023_productaddonsummary"),
    ]

    operations = [
        migrations.AddField(
            model_name="productaddonsummary",
            name="key",
            field=models.CharField(default="", max_length=100),
            preserve_default=False,
        ),
    ]



# Generated by Django 3.2.16 on 2024-08-21 04:48

from decimal import Decimal

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("subscriptionmanager", "0012_merge_20240724_0436"),
    ]

    operations = [
        migrations.CreateModel(
            name="RollForwardSummary",
            fields=[
                (
                    "id",
                    models.BigAutoField(
                        auto_created=True,
                        primary_key=True,
                        serialize=False,
                        verbose_name="ID",
                    ),
                ),
                ("last_synced", models.DateTimeField()),
                ("month", models.DateField()),
                ("customer_account_code", models.CharField(max_length=50)),
                ("billing_entity", models.CharField(max_length=250)),
                ("subscription_guid", models.UUIDField()),
                ("currency", models.CharField(max_length=3)),
                (
                    "won_mrr",
                    models.DecimalField(
                        decimal_places=2, default=Decimal("0.00"), max_digits=10
                    ),
                ),
                (
                    "contracted_mrr",
                    models.DecimalField(
                        decimal_places=2, default=Decimal("0.00"), max_digits=10
                    ),
                ),
                (
                    "user_expansion",
                    models.DecimalField(
                        decimal_places=2, default=Decimal("0.00"), max_digits=10
                    ),
                ),
                (
                    "user_expansion_mom",
                    models.DecimalField(
                        decimal_places=2, default=Decimal("0.00"), max_digits=10
                    ),
                ),
                (
                    "upgrade",
                    models.DecimalField(
                        decimal_places=2, default=Decimal("0.00"), max_digits=10
                    ),
                ),
                (
                    "downgrade",
                    models.DecimalField(
                        decimal_places=2, default=Decimal("0.00"), max_digits=10
                    ),
                ),
                (
                    "upgrade_or_downgrade",
                    models.DecimalField(
                        decimal_places=2, default=Decimal("0.00"), max_digits=10
                    ),
                ),
                (
                    "churn_from_live",
                    models.DecimalField(
                        decimal_places=2, default=Decimal("0.00"), max_digits=10
                    ),
                ),
                (
                    "churn_from_not_live",
                    models.DecimalField(
                        decimal_places=2, default=Decimal("0.00"), max_digits=10
                    ),
                ),
                (
                    "billable_mrr",
                    models.DecimalField(
                        decimal_places=2, default=Decimal("0.00"), max_digits=10
                    ),
                ),
                (
                    "mmr_transfered",
                    models.DecimalField(
                        decimal_places=2, default=Decimal("0.00"), max_digits=10
                    ),
                ),
                (
                    "contracted_discount_mrr",
                    models.DecimalField(
                        decimal_places=2, default=Decimal("0.00"), max_digits=10
                    ),
                ),
                (
                    "delayed_onboarding_mrr",
                    models.DecimalField(
                        decimal_places=2, default=Decimal("0.00"), max_digits=10
                    ),
                ),
                (
                    "other_credit_mrr",
                    models.DecimalField(
                        decimal_places=2, default=Decimal("0.00"), max_digits=10
                    ),
                ),
                ("note", models.TextField(blank=True)),
            ],
            options={
                "db_table": 'subscriptionmanager"."roll_forward_summary',
                "managed": True,
                "default_permissions": (),
            },
        ),
    ]



# Generated by Django 3.2.16 on 2023-10-26 14:39

import datetime

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("workforce", "0009_templatestatsummary"),
    ]

    operations = [
        migrations.AlterField(
            model_name="usagemetrics",
            name="for_date",
            field=models.DateField(db_index=True, default=datetime.date.today),
            preserve_default=False,
        ),
    ]



# Generated by Django 3.2.16 on 2024-01-17 00:29

from django.db import migrations


class Migration(migrations.Migration):
    dependencies = [
        ("workforce", "0012_auto_20240117_0012"),
    ]

    operations = [
        migrations.RenameField(
            model_name="synceddata",
            old_name="oauth_state",
            new_name="data",
        ),
    ]



# Generated by Django 4.2.16 on 2025-02-12 21:35

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        (
            "subscriptionmanager",
            "0016_alter_workspace_name_alter_workspace_tags_and_more",
        ),
    ]

    operations = [
        migrations.CreateModel(
            name="AccountCodeMap",
            fields=[
                (
                    "id",
                    models.BigAutoField(
                        auto_created=True,
                        primary_key=True,
                        serialize=False,
                        verbose_name="ID",
                    ),
                ),
                ("entity_name", models.CharField(max_length=200)),
                ("local_account_name", models.CharField(max_length=200)),
                ("group_account_name", models.CharField(max_length=200)),
                ("last_synced", models.DateTimeField(db_index=True)),
            ],
            options={
                "db_table": 'subscriptionmanager"."account_code_map',
                "managed": True,
                "default_permissions": (),
            },
        ),
    ]



from django.contrib.postgres.fields import ArrayField
from django.core.serializers.json import DjangoJSONEncoder
from django.db import connection, models

from .. import model_settings


class WorkforceAddressSummary(models.Model):
    class Countries(models.TextChoices):
        AU = "AU", "Australia"
        NZ = "NZ", "New Zealand"

    tenant = models.CharField(db_index=True, max_length=200)
    last_synced = models.DateTimeField(null=True)
    prop_status = models.CharField(max_length=30, blank=True)
    prop_id = models.IntegerField()
    prop_created = models.DateTimeField(null=True)
    address = models.CharField(
        max_length=1000,
        blank=True,
        help_text="Exact and validated registered postal address.",
    )
    display = models.TextField(
        max_length=1000,
        blank=False,
        help_text="Address that will be used for display purposes.",
    )
    country = models.CharField(
        max_length=2, blank=True, default="AU", choices=Countries.choices
    )
    gnaf_id = models.CharField(max_length=30, default="", blank=True)
    state = models.CharField(
        max_length=50, blank=True, default="", verbose_name="State or Region"
    )
    postal_code = models.CharField(
        max_length=15, blank=True, default="", verbose_name="Postal or Zip code"
    )
    coords = models.CharField(max_length=40, blank=True)

    class Meta:
        managed = model_settings.DATAWAREHOUSE_MANAGED_MODELS
        app_label = "workforce"
        default_permissions = ()
        db_table = 'workforce"."address_summary'


class ConstanceSetting(models.Model):
    slug = models.CharField(max_length=100)
    setting_name = models.TextField()
    setting_value = models.TextField(null=True)
    last_synced = models.DateTimeField(null=True)

    class Meta:
        managed = model_settings.DATAWAREHOUSE_MANAGED_MODELS
        app_label = "workforce"
        default_permissions = ()
        db_table = 'workforce"."constance_summary'


class ExtensionSummary(models.Model):
    tenant = models.CharField(db_index=True, max_length=200)
    name = models.CharField(max_length=100)
    is_enabled = models.BooleanField(db_index=True)
    last_synced = models.DateTimeField(null=True)

    class Meta:
        managed = model_settings.DATAWAREHOUSE_MANAGED_MODELS
        app_label = "workforce"
        default_permissions = ()
        db_table = 'workforce"."extension_summary'


class FeatureFlagSummary(models.Model):
    tenant = models.CharField(db_index=True, max_length=200)
    name = models.CharField(max_length=100)
    is_enabled = models.BooleanField(db_index=True)
    last_synced = models.DateTimeField(null=True)

    class Meta:
        managed = model_settings.DATAWAREHOUSE_MANAGED_MODELS
        app_label = "workforce"
        default_permissions = ()
        db_table = 'workforce"."featureflag_summary'


class UserSummaryRow(models.Model):
    last_synced = models.DateTimeField(db_index=True)
    tenant = models.CharField(db_index=True, max_length=200)
    user_pk = models.PositiveIntegerField(db_index=True)
    email = models.CharField(max_length=255, db_index=True)
    name = models.CharField(max_length=255)
    license = models.CharField(max_length=10, db_index=True)
    is_active = models.BooleanField(db_index=True)
    is_superuser = models.BooleanField(db_index=True)
    created = models.DateTimeField(db_index=True)
    last_access = models.DateTimeField(null=True, blank=True, db_index=True)
    groups = ArrayField(models.CharField(max_length=150), default=list, blank=True)
    addons = ArrayField(models.CharField(max_length=150), default=list, blank=True)

    class Meta:
        managed = model_settings.DATAWAREHOUSE_MANAGED_MODELS
        app_label = "workforce"
        default_permissions = ()
        db_table = 'workforce"."customer_all_users'


class CustomReportSummary(models.Model):
    """Custom reports are collected to support running regression tests."""

    tenant = models.CharField(db_index=True, max_length=200)
    last_synced = models.DateTimeField(db_index=True)
    custom_report_pk = models.PositiveIntegerField(db_index=True)
    query = models.TextField()

    class Meta:
        managed = model_settings.DATAWAREHOUSE_MANAGED_MODELS
        app_label = "workforce"
        default_permissions = ()
        db_table = 'workforce"."customer_custom_reports'


class UsageMetrics(models.Model):
    tenant = models.CharField(db_index=True, max_length=200)
    count_name = models.CharField(db_index=True, max_length=200)
    stat_count = models.BigIntegerField()
    for_date = models.DateField(db_index=True)
    as_of = models.DateTimeField(db_index=True)

    class Meta:
        managed = model_settings.DATAWAREHOUSE_MANAGED_MODELS
        app_label = "workforce"
        db_table = 'workforce"."usage_metrics'
        indexes = [
            models.Index(
                fields=["tenant", "count_name", "-as_of"],
                name="usage_metrics_latest_btree",
            ),
            models.Index(
                fields=["tenant", "count_name", "-for_date"],
                name="usage_metrics_date_btree",
            ),
        ]


class ServerUsageData(models.Model):
    workspace = models.CharField(max_length=50, db_index=True)
    for_date = models.DateField(db_index=True)
    as_of = models.DateTimeField()
    usage_key = models.CharField(max_length=100, db_index=True)
    amount = models.IntegerField(default=0)

    # Not sure this'll be used, but here just in case
    data = models.JSONField(blank=True, null=True)

    class Meta:
        managed = model_settings.DATAWAREHOUSE_MANAGED_MODELS
        app_label = "workforce"
        default_permissions = ()
        db_table = 'workforce"."server_usage_data'
        unique_together = ("workspace", "for_date", "usage_key")


class ServerUsage(models.Model):
    """Mechanism for this Workspace to update the datawarehouse with it's resource utilisation for licensing."""

    tenant = models.CharField(max_length=200, db_index=True)
    staff_licenses_total = models.IntegerField()
    staff_licenses_used = models.IntegerField()
    staff_licenses_additional = models.IntegerField()
    desk_licenses_used = models.IntegerField()
    field_licenses_used = models.IntegerField()
    contractor_licenses_used = models.IntegerField()
    customer_licenses_used = models.IntegerField()
    api_licenses_used = models.IntegerField()
    reporting_licenses_used = models.IntegerField()
    timesheet_licenses_used = models.IntegerField()
    contractor_addons_used = models.IntegerField(default=0)
    sms_notifications = models.IntegerField(default=0)
    premium_portal_tenancies = models.IntegerField(default=0)
    premium_portal_buildings = models.IntegerField(default=0)
    last_synced = models.DateTimeField()
    for_date = models.DateField(db_index=True)

    class Meta:
        managed = model_settings.DATAWAREHOUSE_MANAGED_MODELS
        app_label = "workforce"
        default_permissions = ()
        db_table = 'workforce"."licensing_usage'
        unique_together = ("tenant", "for_date")


class TemplateStatSummary(models.Model):
    last_synced = models.DateTimeField(db_index=True)
    tenant = models.CharField(db_index=True, max_length=200)
    object_pk = models.IntegerField()
    object_content_type_name = models.CharField(max_length=100)
    created = models.DateTimeField()
    region = models.CharField(max_length=10)
    name = models.CharField(max_length=250)
    key = models.CharField(max_length=250)
    extends = models.CharField(max_length=250, blank=True, default="")
    usage_total = models.IntegerField()
    usage_this_year = models.IntegerField()
    usage_last_year = models.IntegerField()
    libraries_loaded = ArrayField(
        models.CharField(max_length=250), default=list, blank=True
    )
    deprecated_functions = ArrayField(
        models.CharField(max_length=250), default=list, blank=True
    )
    is_active = models.BooleanField()

    class Meta:
        managed = model_settings.DATAWAREHOUSE_MANAGED_MODELS
        app_label = "workforce"
        db_table = 'workforce"."template_stat_summary'


class SyncedData(models.Model):
    """Upsert entire json payloads into the datawarehouse.

    The purpose is store arbitrary blob payloads (not individual models but json tabular data of low rows)

    Example usecases:
    - all templates
    - all postgres tables and their metrics
    """

    tenant = models.CharField(max_length=200, db_index=True)
    key = models.CharField(max_length=200, db_index=True)
    data = models.JSONField(default=list, encoder=DjangoJSONEncoder)
    last_synced = models.DateTimeField(db_index=True, null=True)

    class Meta:
        managed = model_settings.DATAWAREHOUSE_MANAGED_MODELS
        app_label = "workforce"
        default_permissions = ()
        db_table = 'workforce"."synced_data'
        unique_together = ("tenant", "key")


class Benchmark(models.Model):
    count_name = models.CharField(max_length=200)
    country_cohort = models.CharField(max_length=200)
    size_cohort = models.CharField(max_length=20)
    industry_cohort = models.CharField(max_length=20)
    value = models.DecimalField(max_digits=20, decimal_places=2)
    tenant_count = models.IntegerField()

    @classmethod
    def refresh_view(cls, concurrent: bool = True) -> None:
        query = f"refresh materialized view {"concurrently " if concurrent else ""} workforce.usage_metrics_benchmarks;"
        with connection.cursor() as cursor:
            cursor.execute(query)

    class Meta:
        # Created via a materialized view
        managed = False
        app_label = "workforce"
        default_permissions = ()
        db_table = 'workforce"."usage_metrics_benchmarks'


class LatestUsageMetrics(models.Model):
    """Gets the latest callhome value for each stat, month and workspace"""

    # -- --- Used by: Equals for usage analysis
    workspace = models.CharField(max_length=200)  # was tenant
    account_number = models.CharField(max_length=50)  # was customer_account_number
    subscription_currency = models.CharField(max_length=3)  # was currency
    month_start = models.DateField()
    dimension = models.CharField(max_length=200)  # Was count_name
    value = models.BigIntegerField()  # Was stat_count
    as_of = models.DateTimeField()  # Was as_of

    class Meta:
        managed = model_settings.DATAWAREHOUSE_MANAGED_MODELS
        app_label = "workforce"
        db_table = 'workforce"."mv_usage_metrics_latest'

        constraints = [
            models.UniqueConstraint(
                fields=["workspace", "dimension", "month_start"],
                name="idx_mvusagemetricslatest",
            )
        ]



# Generated by Django 3.2.16 on 2023-01-23 04:43

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        (
            "subscriptionmanager",
            "0002_changesummary_chargesummary_paymentmethodsummary_recurringcreditsummary_revenueforecastsummary_subsc",
        ),
    ]

    operations = [
        migrations.AlterField(
            model_name="chargesummary",
            name="total",
            field=models.DecimalField(decimal_places=2, max_digits=10, null=True),
        ),
        migrations.AlterField(
            model_name="xeroinvoicesummary",
            name="is_sent",
            field=models.BooleanField(default=False, null=True),
        ),
    ]



# Generated by Django 3.2.16 on 2024-06-23 21:42

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("subscriptionmanager", "0009_subscriptionsummary_billing_entity_name"),
    ]

    operations = [
        migrations.AddField(
            model_name="subscriptionsummary",
            name="superseded_by_guid",
            field=models.UUIDField(blank=True, null=True),
        ),
        migrations.AddField(
            model_name="subscriptionsummary",
            name="superseded_subscription_contract_value",
            field=models.DecimalField(
                blank=True, decimal_places=2, max_digits=10, null=True
            ),
        ),
        migrations.AddField(
            model_name="subscriptionsummary",
            name="superseded_subscription_guid",
            field=models.UUIDField(blank=True, null=True),
        ),
        migrations.AddField(
            model_name="subscriptionsummary",
            name="superseded_subscription_upgrade_or_downgrade_amount",
            field=models.DecimalField(
                blank=True, decimal_places=2, max_digits=10, null=True
            ),
        ),
    ]



# Generated by Django 4.2.16 on 2025-04-06 05:46

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("subscriptionmanager", "0020_rollforwardsummary_customer_group_code_and_more"),
    ]

    operations = [
        migrations.AddField(
            model_name="addonsummary",
            name="price_eur",
            field=models.DecimalField(
                blank=True, decimal_places=2, max_digits=10, null=True
            ),
        ),
        migrations.AddField(
            model_name="plansummary",
            name="price_eur",
            field=models.DecimalField(
                blank=True, decimal_places=2, max_digits=10, null=True
            ),
        ),
    ]



# Generated by Django 4.2.16 on 2025-04-10 02:05

from django.db import migrations


class Migration(migrations.Migration):
    dependencies = [
        ("workforce", "0020_materialiezdusagemetrics"),
    ]

    operations = [
        migrations.DeleteModel(
            name="OnboardingActionRow",
        ),
        migrations.DeleteModel(
            name="TemplateChangeRequestSummary",
        ),
    ]



# Generated by Django 3.2.16 on 2024-05-16 02:57

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("subscriptionmanager", "0006_alter_reporting_fx_rate_2024_04_15"),
    ]

    operations = [
        migrations.CreateModel(
            name="AddonSummary",
            fields=[
                (
                    "id",
                    models.BigAutoField(
                        auto_created=True,
                        primary_key=True,
                        serialize=False,
                        verbose_name="ID",
                    ),
                ),
                ("name", models.CharField(max_length=100)),
                ("category", models.CharField(blank=True, max_length=100)),
                ("equivalent", models.CharField(blank=True, max_length=100)),
                ("metered_value", models.CharField(max_length=50)),
                (
                    "price_aud",
                    models.DecimalField(
                        blank=True, decimal_places=2, max_digits=10, null=True
                    ),
                ),
                (
                    "price_nzd",
                    models.DecimalField(
                        blank=True, decimal_places=2, max_digits=10, null=True
                    ),
                ),
                (
                    "price_gbp",
                    models.DecimalField(
                        blank=True, decimal_places=2, max_digits=10, null=True
                    ),
                ),
                (
                    "price_cad",
                    models.DecimalField(
                        blank=True, decimal_places=2, max_digits=10, null=True
                    ),
                ),
                (
                    "price_usd",
                    models.DecimalField(
                        blank=True, decimal_places=2, max_digits=10, null=True
                    ),
                ),
                ("is_current", models.BooleanField(default=True)),
            ],
            options={
                "db_table": 'subscriptionmanager"."billing_addon_summary',
                "managed": True,
                "default_permissions": (),
            },
        ),
        migrations.CreateModel(
            name="PlanSummary",
            fields=[
                (
                    "id",
                    models.BigAutoField(
                        auto_created=True,
                        primary_key=True,
                        serialize=False,
                        verbose_name="ID",
                    ),
                ),
                ("name", models.CharField(max_length=100)),
                ("category", models.CharField(blank=True, max_length=100)),
                ("equivalent", models.CharField(blank=True, max_length=100)),
                ("included_users", models.IntegerField()),
                (
                    "price_aud",
                    models.DecimalField(
                        blank=True, decimal_places=2, max_digits=10, null=True
                    ),
                ),
                (
                    "price_nzd",
                    models.DecimalField(
                        blank=True, decimal_places=2, max_digits=10, null=True
                    ),
                ),
                (
                    "price_gbp",
                    models.DecimalField(
                        blank=True, decimal_places=2, max_digits=10, null=True
                    ),
                ),
                (
                    "price_cad",
                    models.DecimalField(
                        blank=True, decimal_places=2, max_digits=10, null=True
                    ),
                ),
                (
                    "price_usd",
                    models.DecimalField(
                        blank=True, decimal_places=2, max_digits=10, null=True
                    ),
                ),
                (
                    "recommended_addon_name",
                    models.CharField(blank=True, max_length=100),
                ),
                ("is_current", models.BooleanField(default=True)),
                ("expects_licensing_usage", models.BooleanField(default=True)),
            ],
            options={
                "db_table": 'subscriptionmanager"."billing_plan_summary',
                "managed": True,
                "default_permissions": (),
            },
        ),
        migrations.AddField(
            model_name="subscriptionsummary",
            name="termination_notification_date",
            field=models.DateField(blank=True, null=True),
        ),
    ]



# Generated by Django 4.2.16 on 2025-07-01 08:25

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("subscriptionmanager", "0027_alter_xeroinvoicesummary_reference"),
    ]

    operations = [
        migrations.CreateModel(
            name="FixedFXRate",
            fields=[
                (
                    "id",
                    models.BigAutoField(
                        auto_created=True,
                        primary_key=True,
                        serialize=False,
                        verbose_name="ID",
                    ),
                ),
                ("currency", models.CharField(max_length=3)),
                ("rate", models.DecimalField(decimal_places=4, max_digits=10)),
                ("applicable_from", models.DateField(blank=True, null=True)),
                ("applicable_to", models.DateField(blank=True, null=True)),
            ],
            options={
                "db_table": 'subscriptionmanager"."fixed_fx_rate',
                "managed": True,
                "default_permissions": (),
            },
        ),
    ]
